<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>LXQtMainMenu</name>
    <message>
        <location filename="../../../lxqtmainmenu.cpp" line="96"/>
        <source>Search...</source>
        <translation>搜索...</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenu.cpp" line="102"/>
        <source>Show/hide main menu</source>
        <translation>显示/隐藏主菜单</translation>
    </message>
    <message>
        <source>Leave</source>
        <translation type="vanished">离开</translation>
    </message>
</context>
<context>
    <name>LXQtMainMenuConfiguration</name>
    <message>
        <source>LXQt Main Menu settings</source>
        <translation type="vanished">LXQt主菜单设置</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>常规</translation>
    </message>
    <message>
        <source>Show text</source>
        <translation type="vanished">显示文本</translation>
    </message>
    <message>
        <source>Button text</source>
        <translation type="vanished">按钮文本</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="14"/>
        <source>Main Menu settings</source>
        <translation>主菜单设置</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="35"/>
        <source>Icon:</source>
        <translation>图标:</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="59"/>
        <source>Button text:</source>
        <translation>按钮文字:</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="76"/>
        <source>Custom font size:</source>
        <translation>自定义字体大小:</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="86"/>
        <source> pt</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="105"/>
        <source>Menu file</source>
        <translation>菜单文件</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="111"/>
        <source>Menu file:</source>
        <translation>菜单文件:</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="156"/>
        <source>Search</source>
        <translation>搜索</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="162"/>
        <source>max. item width:</source>
        <translation>最大项目宽度:</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="169"/>
        <source>Show matching entries:</source>
        <translation>显示匹配的快捷方式:</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="183"/>
        <source>Maximum visible items:</source>
        <translation>最大可见项目数:</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="190"/>
        <source>Filter menu entries</source>
        <translation>过滤菜单快捷方式</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="197"/>
        <source> px</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="210"/>
        <source>Hide menu entries while searching</source>
        <translation>搜索时隐藏菜单快捷方式</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="217"/>
        <source>Clear search upon showing menu</source>
        <translation>清除显示菜单上的搜索</translation>
    </message>
    <message>
        <source>...</source>
        <translation type="vanished">...</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="127"/>
        <source>Keyboard Shortcut</source>
        <translation>键盘快捷键</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="146"/>
        <source>Click the button to record shortcut:</source>
        <translation>单击按钮记录快捷键:</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.cpp" line="71"/>
        <source>Reset</source>
        <translation>重置</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.cpp" line="165"/>
        <source>Choose icon file</source>
        <translation>选择图标文件</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.cpp" line="167"/>
        <source>Images (*.svg *.png)</source>
        <translation>图像 (*.svg *.png)</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.cpp" line="179"/>
        <source>Choose menu file</source>
        <translation>选择菜单文件</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.cpp" line="181"/>
        <source>Menu files (*.menu)</source>
        <translation>菜单文件 (*.menu)</translation>
    </message>
</context>
</TS>
